local awful = require("awful")
local gears = require("gears")
local wibox = require("wibox")
local awmtk = require("awmtk")

return function(args)
    local style = awmtk.style(awmtk.defaults, args.style or {},"battery_")
    local device = args.device or "default"
    local power_command = args.command or "upower -d"
    local function get_icon(name)
        return style[name]
    end
    local icon = style.icon({
        {
            widget = wibox.widget.imagebox,
            image = get_icon("battery_missing_symbolic"),
            id = "widget_icon",
            resize = true
        },
        (args.percentage and {
            widget = wibox.widget.textbox,
            markup = "0%",
            id = "widget_text"
        }),
        layout = wibox.layout.fixed.horizontal,
        spacing = style.battery_container_spacing_horizontal
    })
    gears.timer {
        autostart = true,
        timeout = 10,
        call_now = true,
        callback = function()
            awful.spawn.easy_async_with_shell(power_command, function(out)
                local icon_name = out:match("icon%-name:%s+'(battery%-[^']+)'")
                local value = out:match("percentage:%s+(%d+%%)")
                icon:get_children_by_id("widget_icon")[1].image = 
                    gears.color.recolor_image(get_icon(icon_name:gsub("%-","_")),
                        style.battery_icon_fg_normal)
                if args.percentage and value then
                    icon:get_children_by_id("widget_text")[1].markup = value
                end
            end)
        end
    }
    return icon
end
